==> dvisvgm-2.2.2.tar.gz: dvisvgm-2.2.2/src/FontMetrics.cpp <==
/*************************************************************************
** FontMetrics.cpp                                                      **
**                                                                      **
** This file is part of dvisvgm -- a fast DVI to SVG converter          **
** Copyright (C) 2005-2017 Martin Gieseking <martin.gieseking@uos.de>   **
**                                                                      **
** This program is free software; you can redistribute it and/or        **
** modify it under the terms of the GNU General Public License as       **
** published by the Free Software Foundation; either version 3 of       **
** the License, or (at your option) any later version.                  **
**                                                                      **
** This program is distributed in the hope that it will be useful, but  **
** WITHOUT ANY WARRANTY; without even the implied warranty of           **
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the         **
** GNU General Public License for more details.                         **
**                                                                      **
** You should have received a copy of the GNU General Public License    **
** along with this program; if not, see <http://www.gnu.org/licenses/>. **
*************************************************************************/

#include <fstream>
#include <memory>
#include "FileFinder.hpp"
#include "FontMetrics.hpp"
#include "JFM.hpp"
#include "utility.hpp"

using namespace std;


unique_ptr<FontMetrics> FontMetrics::read (const char *fontname) {
	const char *path = FileFinder::instance().lookup(string(fontname) + ".tfm");
	ifstream ifs(path, ios::binary);
	if (!ifs)
		return unique_ptr<FontMetrics>();
	uint16_t id = 256*ifs.get();
	id += ifs.get();
	if (id == 9 || id == 11)  // Japanese font metric file?
		return util::make_unique<JFM>(ifs);
	return util::make_unique<TFM>(ifs);
}

==> dvisvgm_2.8.2.orig.tar.gz: dvisvgm-2.8.2/src/FontMetrics.cpp <==
/*************************************************************************
** FontMetrics.cpp                                                      **
**                                                                      **
** This file is part of dvisvgm -- a fast DVI to SVG converter          **
** Copyright (C) 2005-2019 Martin Gieseking <martin.gieseking@uos.de>   **
**                                                                      **
** This program is free software; you can redistribute it and/or        **
** modify it under the terms of the GNU General Public License as       **
** published by the Free Software Foundation; either version 3 of       **
** the License, or (at your option) any later version.                  **
**                                                                      **
** This program is distributed in the hope that it will be useful, but  **
** WITHOUT ANY WARRANTY; without even the implied warranty of           **
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the         **
** GNU General Public License for more details.                         **
**                                                                      **
** You should have received a copy of the GNU General Public License    **
** along with this program; if not, see <http://www.gnu.org/licenses/>. **
*************************************************************************/

#include <fstream>
#include <memory>
#include "FileFinder.hpp"
#include "FontMetrics.hpp"
#include "JFM.hpp"
#include "utility.hpp"

using namespace std;


unique_ptr<FontMetrics> FontMetrics::read (const string &fontname) {
	const char *path = FileFinder::instance().lookup(fontname + ".tfm");
	ifstream ifs(path, ios::binary);
	if (!ifs)
		return unique_ptr<FontMetrics>();
	uint16_t id = 256*ifs.get();
	id += ifs.get();
	if (id == 9 || id == 11)  // Japanese font metric file?
		return util::make_unique<JFM>(ifs);
	return util::make_unique<TFM>(ifs);
}
